# DSCI-310-Group-10-Package

DSCI-310-Group-10-Package is a Python package for the investment income outcome analysis done for DSCI310. This package is largely dependent on the scikit-learn and matplotlib packages, and is distributed under the MIT License.

The functions in this package have roles related to hyperparamater optimizations for specific machine learning models, and plot the results obtained.

The main project where this package is used can be found in the following GitHub Repository: https://github.com/DSCI-310/DSCI-310-Group-10

## Installation

```bash
$ pip install group10pack
```

## Usage

- [example](docs/example.ipynb)


## Contributing

Interested in contributing? Check out the contributing guidelines. Please note that this project is released with a Code of Conduct. By contributing to this project, you agree to abide by its terms.

## License

`DSCI-310-Group-10-Package` was created by Harry Zhang Ahmed Rizk Mahdi Heydar Nikko Dumrique. It is licensed under the terms of the MIT license.

## Credits

`DSCI-310-Group-10-Package` was created with [`cookiecutter`](https://cookiecutter.readthedocs.io/en/latest/) and the `py-pkgs-cookiecutter` [template](https://github.com/py-pkgs/py-pkgs-cookiecutter).

### License
This project is licensed under the MIT License and [Creative Commons Attribution-NonCommerical-NoDerivatives 4.0 International License](https://creativecommons.org/licenses/by-nc-nd/4.0/)
<a rel="license" href="http://creativecommons.org/licenses/by-nc-nd/4.0/"><img alt="Creative Commons License" style="border-width:1" src="https://i.creativecommons.org/l/by-nc-nd/4.0/88x31.png" /></a><br />
